﻿var settings = {
    tenantUrl: "https://tenant.sharepoint.com",
    webUrl: "/",  //Note:for root web set url to '/'
    username: "username@tenant.onmicrosoft.com",
    password: ""
};

exports.settings = settings;
